@@ -19,7 +19,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  
  */
 
-static char rcsid[] ="$Id: multi.c,v 1.6.1.1 1997/10/13 02:46:46 eric Exp $";
+static char rcsid[] ="$Id: multi.c,v 1.6.1.2 1997/11/09 16:35:42 eric Exp $";
 
 #include <stdlib.h>
 #include <string.h>
@@ -457,7 +457,9 @@ FDECL2(read_merging_directory, struct iso_directory_record *, mrootp,
 			  rlen) == 0 
 		  && cpnt[2+rlen] == ' ')
 		{
-		  (*pnt)->table = strdup((char *) cpnt);
+		  (*pnt)->table = e_malloc(strlen((char*)cpnt) - 34);
+		  sprintf((*pnt)->table, "%c\t%s\n",
+			  *cpnt, cpnt+37);
 		  if( (*pnt)->name == NULL )
 		    {
 		      (*pnt)->name = strdup((char *) cpnt+37);
