@@ -19,7 +19,7 @@
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
 
-static char rcsid[] ="$Id: rock.c,v 1.2 1997/02/23 16:08:07 eric Rel $";
+static char rcsid[] ="$Id: rock.c,v 1.3 1997/05/17 15:45:26 eric Exp $";
 
 #include <stdlib.h>
 
@@ -225,7 +225,7 @@ int deep_opt;
     Rock[ipnt++] = PN_SIZE;
     Rock[ipnt++] = SU_VERSION;  
     flagval |= (1<<1);
-#if MAJOR_IN_SYSMACROS == 0 && MAJOR_IN_MKDEV == 0
+#if !defined(MAJOR_IN_SYSMACROS) && !defined(MAJOR_IN_MKDEV)
     set_733((char*)Rock + ipnt, major(lstatbuf->st_rdev ));
     ipnt += 8;
     set_733((char*)Rock + ipnt, minor(lstatbuf->st_rdev));
