@@ -20,7 +20,7 @@
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
 
-static char rcsid[] ="$Id: tree.c,v 1.9 1997/06/27 11:24:20 eric Exp $";
+static char rcsid[] ="$Id: tree.c,v 1.9.1.1 1997/11/09 16:36:10 eric Exp $";
 
 /* ADD_FILES changes made by Ross Biro biro@yggdrasil.com 2/23/95 */
 
@@ -384,7 +384,6 @@ got_valid_name:
 
   if(table)
     {
-      char buffer[1024];
       count = 0;
       for (s_entry = this_dir->contents; s_entry; s_entry = s_entry->next){
 	if(s_entry == table) continue;
@@ -392,10 +391,9 @@ got_valid_name:
 	if(strcmp(s_entry->name, ".") == 0  ||
 	   strcmp(s_entry->name, "..") == 0) continue;
 	
-	sprintf(buffer,"%c %-34s%s",s_entry->table[0],  
-		s_entry->isorec.name, s_entry->table+1);
-	memcpy(table->table + count, buffer, strlen(buffer));
-	count +=  strlen(buffer);
+	count += sprintf(table->table + count, "%c %-34s%s",
+			 s_entry->table[0],
+			 s_entry->isorec.name, s_entry->table+1);
 	free(s_entry->table);
 	s_entry->table = NULL;
       }
@@ -1158,6 +1156,13 @@ FDECL3(scan_directory_tree,char *, path, struct directory_entry *, de,
       free_mdinfo(orig_contents, n_orig);
     }
 
+  if( this_dir->contents == NULL )
+    {
+      /*
+       * This directory must have been inaccessible.
+       */
+      return 0;
+    }
   sort_n_finish(this_dir);
 
   return 1;
