@@ -19,7 +19,7 @@
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
 
-static char rcsid[] ="$Id: write.c,v 1.6.1.1 1997/10/13 02:46:00 eric Exp $";
+static char rcsid[] ="$Id: write.c,v 1.6.1.3 1997/11/13 05:07:13 eric Exp $";
 
 #include <string.h>
 #include <stdlib.h>
@@ -327,8 +327,8 @@ int FDECL2(compare_dirs, const void *, rr, const void *, ll)
 	  if(*rpnt == '.' && *lpnt != '.') return -1;
 	  if(*rpnt != '.' && *lpnt == '.') return 1;
 	  
-	  if(*rpnt < *lpnt) return -1;
-	  if(*rpnt > *lpnt) return 1;
+	  if((unsigned char)*rpnt < (unsigned char)*lpnt) return -1;
+	  if((unsigned char)*rpnt > (unsigned char)*lpnt) return 1;
 	  rpnt++;  lpnt++;
      }
      if(*rpnt) return 1;
